==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/CassandraResourceCassandraTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin

import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs.builder
import com.pulumi.azurenative.documentdb.kotlin.inputs.CassandraTableResourceArgs
import com.pulumi.azurenative.documentdb.kotlin.inputs.CassandraTableResourceArgsBuilder
import com.pulumi.azurenative.documentdb.kotlin.inputs.CreateUpdateOptionsArgs
import com.pulumi.azurenative.documentdb.kotlin.inputs.CreateUpdateOptionsArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * An Azure Cosmos DB Cassandra table.
 * Azure REST API version: 2023-04-15. Prior API version in Azure Native 1.x: 2021-03-15.
 * Other available API versions: 2019-08-01, 2023-03-15-preview, 2023-09-15, 2023-09-15-preview.
 * ## Example Usage
 * ### CosmosDBCassandraTableCreateUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cassandraResourceCassandraTable = new AzureNative.DocumentDB.CassandraResourceCassandraTable("cassandraResourceCassandraTable", new()
 *     {
 *         AccountName = "ddb1",
 *         KeyspaceName = "keyspaceName",
 *         Location = "West US",
 *         Options = null,
 *         Resource = new AzureNative.DocumentDB.Inputs.CassandraTableResourceArgs
 *         {
 *             DefaultTtl = 100,
 *             Id = "tableName",
 *             Schema = new AzureNative.DocumentDB.Inputs.CassandraSchemaArgs
 *             {
 *                 ClusterKeys = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.ClusterKeyArgs
 *                     {
 *                         Name = "columnA",
 *                         OrderBy = "Asc",
 *                     },
 *                 },
 *                 Columns = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.ColumnArgs
 *                     {
 *                         Name = "columnA",
 *                         Type = "Ascii",
 *                     },
 *                 },
 *                 PartitionKeys = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.CassandraPartitionKeyArgs
 *                     {
 *                         Name = "columnA",
 *                     },
 *                 },
 *             },
 *         },
 *         ResourceGroupName = "rg1",
 *         TableName = "tableName",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/documentdb/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := documentdb.NewCassandraResourceCassandraTable(ctx, "cassandraResourceCassandraTable", &documentdb.CassandraResourceCassandraTableArgs{
 * AccountName: pulumi.String("ddb1"),
 * KeyspaceName: pulumi.String("keyspaceName"),
 * Location: pulumi.String("West US"),
 * Options: nil,
 * Resource: documentdb.CassandraTableGetPropertiesResponseResource{
 * DefaultTtl: pulumi.Int(100),
 * Id: pulumi.String("tableName"),
 * Schema: interface{}{
 * ClusterKeys: documentdb.ClusterKeyArray{
 * &documentdb.ClusterKeyArgs{
 * Name: pulumi.String("columnA"),
 * OrderBy: pulumi.String("Asc"),
 * },
 * },
 * Columns: documentdb.ColumnArray{
 * &documentdb.ColumnArgs{
 * Name: pulumi.String("columnA"),
 * Type: pulumi.String("Ascii"),
 * },
 * },
 * PartitionKeys: documentdb.CassandraPartitionKeyArray{
 * &documentdb.CassandraPartitionKeyArgs{
 * Name: pulumi.String("columnA"),
 * },
 * },
 * },
 * },
 * ResourceGroupName: pulumi.String("rg1"),
 * TableName: pulumi.String("tableName"),
 * Tags: nil,
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTable;
 * import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cassandraResourceCassandraTable = new CassandraResourceCassandraTable("cassandraResourceCassandraTable", CassandraResourceCassandraTableArgs.builder()
 *             .accountName("ddb1")
 *             .keyspaceName("keyspaceName")
 *             .location("West US")
 *             .options()
 *             .resource(Map.ofEntries(
 *                 Map.entry("defaultTtl", 100),
 *                 Map.entry("id", "tableName"),
 *                 Map.entry("schema", Map.ofEntries(
 *                     Map.entry("clusterKeys", Map.ofEntries(
 *                         Map.entry("name", "columnA"),
 *                         Map.entry("orderBy", "Asc")
 *                     )),
 *                     Map.entry("columns", Map.ofEntries(
 *                         Map.entry("name", "columnA"),
 *                         Map.entry("type", "Ascii")
 *                     )),
 *                     Map.entry("partitionKeys", Map.of("name", "columnA"))
 *                 ))
 *             ))
 *             .resourceGroupName("rg1")
 *             .tableName("tableName")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:documentdb:CassandraResourceCassandraTable tableName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DocumentDB/databaseAccounts/{accountName}/cassandraKeyspaces/{keyspaceName}/tables/{tableName}
 * ```
 * @property accountName Cosmos DB database account name.
 * @property keyspaceName Cosmos DB keyspace name.
 * @property location The location of the resource group to which the resource belongs.
 * @property options A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
 * @property resource The standard JSON format of a Cassandra table
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property tableName Cosmos DB table name.
 * @property tags Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
 */
public data class CassandraResourceCassandraTableArgs(
    public val accountName: Output<String>? = null,
    public val keyspaceName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val options: Output<CreateUpdateOptionsArgs>? = null,
    public val resource: Output<CassandraTableResourceArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tableName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs =
        com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .keyspaceName(keyspaceName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resource(resource?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tableName(tableName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [CassandraResourceCassandraTableArgs].
 */
@PulumiTagMarker
public class CassandraResourceCassandraTableArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var keyspaceName: Output<String>? = null

    private var location: Output<String>? = null

    private var options: Output<CreateUpdateOptionsArgs>? = null

    private var resource: Output<CassandraTableResourceArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var tableName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("dkgrnbcbpqauahws")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Cosmos DB keyspace name.
     */
    @JvmName("gandfyhonipcijjs")
    public suspend fun keyspaceName(`value`: Output<String>) {
        this.keyspaceName = value
    }

    /**
     * @param value The location of the resource group to which the resource belongs.
     */
    @JvmName("joknwklkpnymtvml")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("jeumtqnplcpullrw")
    public suspend fun options(`value`: Output<CreateUpdateOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value The standard JSON format of a Cassandra table
     */
    @JvmName("nvlaxvqrmuteiycl")
    public suspend fun resource(`value`: Output<CassandraTableResourceArgs>) {
        this.resource = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("juvepawevutwsudw")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Cosmos DB table name.
     */
    @JvmName("qhdpqekiubxexbbs")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("hnrqevqsvxvwqnhq")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("thbxnmbdbbujxutg")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Cosmos DB keyspace name.
     */
    @JvmName("woewjcnlpchougum")
    public suspend fun keyspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyspaceName = mapped
    }

    /**
     * @param value The location of the resource group to which the resource belongs.
     */
    @JvmName("vgyxmoblrceccaxi")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("nspiaekaomwswpty")
    public suspend fun options(`value`: CreateUpdateOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("ulrutcgiiwsqqhhj")
    public suspend fun options(argument: suspend CreateUpdateOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = CreateUpdateOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value The standard JSON format of a Cassandra table
     */
    @JvmName("qjvokusadhdbmqwi")
    public suspend fun resource(`value`: CassandraTableResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resource = mapped
    }

    /**
     * @param argument The standard JSON format of a Cassandra table
     */
    @JvmName("piwuegodhpfhkboy")
    public suspend fun resource(argument: suspend CassandraTableResourceArgsBuilder.() -> Unit) {
        val toBeMapped = CassandraTableResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.resource = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("gvjkgwxajrygnwva")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB table name.
     */
    @JvmName("qvvwjsvmxrftalrv")
    public suspend fun tableName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    /**
     * @param value Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("sfktkwlekqrwsils")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("vmowhdfxgvrjtfnt")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): CassandraResourceCassandraTableArgs = CassandraResourceCassandraTableArgs(
        accountName = accountName,
        keyspaceName = keyspaceName,
        location = location,
        options = options,
        resource = resource,
        resourceGroupName = resourceGroupName,
        tableName = tableName,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/CassandraResourceCassandraTableArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin

import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs.builder
import com.pulumi.azurenative.documentdb.kotlin.inputs.CassandraTableResourceArgs
import com.pulumi.azurenative.documentdb.kotlin.inputs.CassandraTableResourceArgsBuilder
import com.pulumi.azurenative.documentdb.kotlin.inputs.CreateUpdateOptionsArgs
import com.pulumi.azurenative.documentdb.kotlin.inputs.CreateUpdateOptionsArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * An Azure Cosmos DB Cassandra table.
 * Azure REST API version: 2023-04-15. Prior API version in Azure Native 1.x: 2021-03-15.
 * Other available API versions: 2019-08-01, 2023-03-15-preview, 2023-09-15, 2023-09-15-preview, 2023-11-15, 2023-11-15-preview.
 * ## Example Usage
 * ### CosmosDBCassandraTableCreateUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cassandraResourceCassandraTable = new AzureNative.DocumentDB.CassandraResourceCassandraTable("cassandraResourceCassandraTable", new()
 *     {
 *         AccountName = "ddb1",
 *         KeyspaceName = "keyspaceName",
 *         Location = "West US",
 *         Options = null,
 *         Resource = new AzureNative.DocumentDB.Inputs.CassandraTableResourceArgs
 *         {
 *             DefaultTtl = 100,
 *             Id = "tableName",
 *             Schema = new AzureNative.DocumentDB.Inputs.CassandraSchemaArgs
 *             {
 *                 ClusterKeys = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.ClusterKeyArgs
 *                     {
 *                         Name = "columnA",
 *                         OrderBy = "Asc",
 *                     },
 *                 },
 *                 Columns = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.ColumnArgs
 *                     {
 *                         Name = "columnA",
 *                         Type = "Ascii",
 *                     },
 *                 },
 *                 PartitionKeys = new[]
 *                 {
 *                     new AzureNative.DocumentDB.Inputs.CassandraPartitionKeyArgs
 *                     {
 *                         Name = "columnA",
 *                     },
 *                 },
 *             },
 *         },
 *         ResourceGroupName = "rg1",
 *         TableName = "tableName",
 *         Tags = null,
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/documentdb/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := documentdb.NewCassandraResourceCassandraTable(ctx, "cassandraResourceCassandraTable", &documentdb.CassandraResourceCassandraTableArgs{
 * AccountName: pulumi.String("ddb1"),
 * KeyspaceName: pulumi.String("keyspaceName"),
 * Location: pulumi.String("West US"),
 * Options: nil,
 * Resource: documentdb.CassandraTableGetPropertiesResponseResource{
 * DefaultTtl: pulumi.Int(100),
 * Id: pulumi.String("tableName"),
 * Schema: interface{}{
 * ClusterKeys: documentdb.ClusterKeyArray{
 * &documentdb.ClusterKeyArgs{
 * Name: pulumi.String("columnA"),
 * OrderBy: pulumi.String("Asc"),
 * },
 * },
 * Columns: documentdb.ColumnArray{
 * &documentdb.ColumnArgs{
 * Name: pulumi.String("columnA"),
 * Type: pulumi.String("Ascii"),
 * },
 * },
 * PartitionKeys: documentdb.CassandraPartitionKeyArray{
 * &documentdb.CassandraPartitionKeyArgs{
 * Name: pulumi.String("columnA"),
 * },
 * },
 * },
 * },
 * ResourceGroupName: pulumi.String("rg1"),
 * TableName: pulumi.String("tableName"),
 * Tags: nil,
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTable;
 * import com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cassandraResourceCassandraTable = new CassandraResourceCassandraTable("cassandraResourceCassandraTable", CassandraResourceCassandraTableArgs.builder()
 *             .accountName("ddb1")
 *             .keyspaceName("keyspaceName")
 *             .location("West US")
 *             .options()
 *             .resource(Map.ofEntries(
 *                 Map.entry("defaultTtl", 100),
 *                 Map.entry("id", "tableName"),
 *                 Map.entry("schema", Map.ofEntries(
 *                     Map.entry("clusterKeys", Map.ofEntries(
 *                         Map.entry("name", "columnA"),
 *                         Map.entry("orderBy", "Asc")
 *                     )),
 *                     Map.entry("columns", Map.ofEntries(
 *                         Map.entry("name", "columnA"),
 *                         Map.entry("type", "Ascii")
 *                     )),
 *                     Map.entry("partitionKeys", Map.of("name", "columnA"))
 *                 ))
 *             ))
 *             .resourceGroupName("rg1")
 *             .tableName("tableName")
 *             .tags()
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:documentdb:CassandraResourceCassandraTable tableName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DocumentDB/databaseAccounts/{accountName}/cassandraKeyspaces/{keyspaceName}/tables/{tableName}
 * ```
 * @property accountName Cosmos DB database account name.
 * @property keyspaceName Cosmos DB keyspace name.
 * @property location The location of the resource group to which the resource belongs.
 * @property options A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
 * @property resource The standard JSON format of a Cassandra table
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property tableName Cosmos DB table name.
 * @property tags Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
 */
public data class CassandraResourceCassandraTableArgs(
    public val accountName: Output<String>? = null,
    public val keyspaceName: Output<String>? = null,
    public val location: Output<String>? = null,
    public val options: Output<CreateUpdateOptionsArgs>? = null,
    public val resource: Output<CassandraTableResourceArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val tableName: Output<String>? = null,
    public val tags: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs> {
    override fun toJava(): com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs =
        com.pulumi.azurenative.documentdb.CassandraResourceCassandraTableArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .keyspaceName(keyspaceName?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .options(options?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resource(resource?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .tableName(tableName?.applyValue({ args0 -> args0 }))
            .tags(
                tags?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [CassandraResourceCassandraTableArgs].
 */
@PulumiTagMarker
public class CassandraResourceCassandraTableArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var keyspaceName: Output<String>? = null

    private var location: Output<String>? = null

    private var options: Output<CreateUpdateOptionsArgs>? = null

    private var resource: Output<CassandraTableResourceArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var tableName: Output<String>? = null

    private var tags: Output<Map<String, String>>? = null

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("qxwfbgumhgfvvglb")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Cosmos DB keyspace name.
     */
    @JvmName("uyckedmgyuxcoxqo")
    public suspend fun keyspaceName(`value`: Output<String>) {
        this.keyspaceName = value
    }

    /**
     * @param value The location of the resource group to which the resource belongs.
     */
    @JvmName("avulfclgolsbtqrc")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("eotlidqkpjabhlfw")
    public suspend fun options(`value`: Output<CreateUpdateOptionsArgs>) {
        this.options = value
    }

    /**
     * @param value The standard JSON format of a Cassandra table
     */
    @JvmName("wmnrhooaqdbbqppc")
    public suspend fun resource(`value`: Output<CassandraTableResourceArgs>) {
        this.resource = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("xnduihskcudiqhen")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Cosmos DB table name.
     */
    @JvmName("blrhremukbuyhacb")
    public suspend fun tableName(`value`: Output<String>) {
        this.tableName = value
    }

    /**
     * @param value Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("munwhybmhnwiquxe")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value Cosmos DB database account name.
     */
    @JvmName("ytvdjippyhoinafx")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Cosmos DB keyspace name.
     */
    @JvmName("lyuuhylfltbtyhib")
    public suspend fun keyspaceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.keyspaceName = mapped
    }

    /**
     * @param value The location of the resource group to which the resource belongs.
     */
    @JvmName("adspllthixcninaq")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("abenbfegiymxggec")
    public suspend fun options(`value`: CreateUpdateOptionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.options = mapped
    }

    /**
     * @param argument A key-value pair of options to be applied for the request. This corresponds to the headers sent with the request.
     */
    @JvmName("ivotyonhcdmadtpk")
    public suspend fun options(argument: suspend CreateUpdateOptionsArgsBuilder.() -> Unit) {
        val toBeMapped = CreateUpdateOptionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.options = mapped
    }

    /**
     * @param value The standard JSON format of a Cassandra table
     */
    @JvmName("ueebhxpxjnwyfwms")
    public suspend fun resource(`value`: CassandraTableResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resource = mapped
    }

    /**
     * @param argument The standard JSON format of a Cassandra table
     */
    @JvmName("jinygtwxhlktniun")
    public suspend fun resource(argument: suspend CassandraTableResourceArgsBuilder.() -> Unit) {
        val toBeMapped = CassandraTableResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.resource = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mqsyibwimoshqbbs")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Cosmos DB table name.
     */
    @JvmName("hkaegmsdkbeuvmog")
    public suspend fun tableName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tableName = mapped
    }

    /**
     * @param value Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("lqhqluicxbyqfxuj")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Tags are a list of key-value pairs that describe the resource. These tags can be used in viewing and grouping this resource (across resource groups). A maximum of 15 tags can be provided for a resource. Each tag must have a key no greater than 128 characters and value no greater than 256 characters. For example, the default experience for a template type is set with "defaultExperience": "Cassandra". Current "defaultExperience" values also include "Table", "Graph", "DocumentDB", and "MongoDB".
     */
    @JvmName("gsmmxwxfidcohdde")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    internal fun build(): CassandraResourceCassandraTableArgs = CassandraResourceCassandraTableArgs(
        accountName = accountName,
        keyspaceName = keyspaceName,
        location = location,
        options = options,
        resource = resource,
        resourceGroupName = resourceGroupName,
        tableName = tableName,
        tags = tags,
    )
}
